==> kubernetes-model-kustomize-6.8.1-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/SortOptionsFluent.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SortOptionsFluent<A extends SortOptionsFluent<A>> extends BaseFluent<A>{
  public SortOptionsFluent() {
  }
  public SortOptionsFluent(SortOptions instance) {
    instance = (instance != null ? instance : new SortOptions());

    if (instance != null) {
      this.withLegacySortOptions(instance.getLegacySortOptions());
      this.withOrder(instance.getOrder());
      this.withLegacySortOptions(instance.getLegacySortOptions());
      this.withOrder(instance.getOrder());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private LegacySortOptionsBuilder legacySortOptions;
  private String order;
  private Map<String,Object> additionalProperties;
  public LegacySortOptions buildLegacySortOptions() {
    return this.legacySortOptions!=null ?this.legacySortOptions.build():null;
  }
  public A withLegacySortOptions(LegacySortOptions legacySortOptions) {
    _visitables.get("legacySortOptions").remove(this.legacySortOptions);
    if (legacySortOptions!=null){ this.legacySortOptions= new LegacySortOptionsBuilder(legacySortOptions); _visitables.get("legacySortOptions").add(this.legacySortOptions);} else { this.legacySortOptions = null; _visitables.get("legacySortOptions").remove(this.legacySortOptions); } return (A) this;
  }
  public boolean hasLegacySortOptions() {
    return this.legacySortOptions != null;
  }
  public LegacySortOptionsNested<A> withNewLegacySortOptions() {
    return new LegacySortOptionsNested(null);
  }
  public LegacySortOptionsNested<A> withNewLegacySortOptionsLike(LegacySortOptions item) {
    return new LegacySortOptionsNested(item);
  }
  public LegacySortOptionsNested<A> editLegacySortOptions() {
    return withNewLegacySortOptionsLike(java.util.Optional.ofNullable(buildLegacySortOptions()).orElse(null));
  }
  public LegacySortOptionsNested<A> editOrNewLegacySortOptions() {
    return withNewLegacySortOptionsLike(java.util.Optional.ofNullable(buildLegacySortOptions()).orElse(new LegacySortOptionsBuilder().build()));
  }
  public LegacySortOptionsNested<A> editOrNewLegacySortOptionsLike(LegacySortOptions item) {
    return withNewLegacySortOptionsLike(java.util.Optional.ofNullable(buildLegacySortOptions()).orElse(item));
  }
  public String getOrder() {
    return this.order;
  }
  public A withOrder(String order) {
    this.order=order; return (A) this;
  }
  public boolean hasOrder() {
    return this.order != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SortOptionsFluent that = (SortOptionsFluent) o;
    if (!java.util.Objects.equals(legacySortOptions, that.legacySortOptions)) return false;

    if (!java.util.Objects.equals(order, that.order)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(legacySortOptions,  order,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (legacySortOptions != null) { sb.append("legacySortOptions:"); sb.append(legacySortOptions + ","); }
    if (order != null) { sb.append("order:"); sb.append(order + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class LegacySortOptionsNested<N> extends LegacySortOptionsFluent<LegacySortOptionsNested<N>> implements Nested<N>{
    LegacySortOptionsNested(LegacySortOptions item) {
      this.builder = new LegacySortOptionsBuilder(this, item);
    }
    LegacySortOptionsBuilder builder;
    public N and() {
      return (N) SortOptionsFluent.this.withLegacySortOptions(builder.build());
    }
    public N endLegacySortOptions() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-kustomize-6.9.0-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/SortOptionsFluent.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class SortOptionsFluent<A extends SortOptionsFluent<A>> extends BaseFluent<A>{
  public SortOptionsFluent() {
  }
  
  public SortOptionsFluent(SortOptions instance) {
    this.copyInstance(instance);
  }
  private LegacySortOptionsBuilder legacySortOptions;
  private String order;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(SortOptions instance) {
    instance = (instance != null ? instance : new SortOptions());
  
    if (instance != null) {
        this.withLegacySortOptions(instance.getLegacySortOptions());
        this.withOrder(instance.getOrder());
        this.withLegacySortOptions(instance.getLegacySortOptions());
        this.withOrder(instance.getOrder());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public LegacySortOptions buildLegacySortOptions() {
    return this.legacySortOptions!=null ?this.legacySortOptions.build():null;
  }
  
  public A withLegacySortOptions(LegacySortOptions legacySortOptions) {
    _visitables.get("legacySortOptions").remove(this.legacySortOptions);
    if (legacySortOptions!=null){ this.legacySortOptions= new LegacySortOptionsBuilder(legacySortOptions); _visitables.get("legacySortOptions").add(this.legacySortOptions);} else { this.legacySortOptions = null; _visitables.get("legacySortOptions").remove(this.legacySortOptions); } return (A) this;
  }
  
  public boolean hasLegacySortOptions() {
    return this.legacySortOptions != null;
  }
  
  public LegacySortOptionsNested<A> withNewLegacySortOptions() {
    return new LegacySortOptionsNested(null);
  }
  
  public LegacySortOptionsNested<A> withNewLegacySortOptionsLike(LegacySortOptions item) {
    return new LegacySortOptionsNested(item);
  }
  
  public LegacySortOptionsNested<A> editLegacySortOptions() {
    return withNewLegacySortOptionsLike(java.util.Optional.ofNullable(buildLegacySortOptions()).orElse(null));
  }
  
  public LegacySortOptionsNested<A> editOrNewLegacySortOptions() {
    return withNewLegacySortOptionsLike(java.util.Optional.ofNullable(buildLegacySortOptions()).orElse(new LegacySortOptionsBuilder().build()));
  }
  
  public LegacySortOptionsNested<A> editOrNewLegacySortOptionsLike(LegacySortOptions item) {
    return withNewLegacySortOptionsLike(java.util.Optional.ofNullable(buildLegacySortOptions()).orElse(item));
  }
  
  public String getOrder() {
    return this.order;
  }
  
  public A withOrder(String order) {
    this.order=order; return (A) this;
  }
  
  public boolean hasOrder() {
    return this.order != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SortOptionsFluent that = (SortOptionsFluent) o;
    if (!java.util.Objects.equals(legacySortOptions, that.legacySortOptions)) return false;
  
    if (!java.util.Objects.equals(order, that.order)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(legacySortOptions,  order,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (legacySortOptions != null) { sb.append("legacySortOptions:"); sb.append(legacySortOptions + ","); }
    if (order != null) { sb.append("order:"); sb.append(order + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class LegacySortOptionsNested<N> extends LegacySortOptionsFluent<LegacySortOptionsNested<N>> implements Nested<N>{
    LegacySortOptionsNested(LegacySortOptions item) {
      this.builder = new LegacySortOptionsBuilder(this, item);
    }
    LegacySortOptionsBuilder builder;
    
    public N and() {
      return (N) SortOptionsFluent.this.withLegacySortOptions(builder.build());
    }
    
    public N endLegacySortOptions() {
      return and();
    }
    
  
  }

}
